       IDENTIFICATION DIVISION.
       PROGRAM-ID.    SIMORA12.
       AUTHOR.        SIMOTIME TECHNOLOGIES.
      *****************************************************************
      * Copyright (C) 1987-2019 SimoTime Technologies.                *
      *                                                               *
      * All rights reserved.  Unpublished, all rights reserved under  *
      * copyright law and international treaty.  Use of a copyright   *
      * notice is precautionary only and does not imply publication   *
      * or disclosure.                                                *
      *                                                               *
      * Permission to use, copy, modify and distribute this software  *
      * for any commercial purpose requires a fee to be paid to       *
      * SimoTime Technologies. Once the fee is received by SimoTime   *
      * the latest version of the software will be delivered and a    *
      * license will be granted for use within an enterprise,         *
      * provided the SimoTime copyright notice appear on all copies   *
      * of the software. The SimoTime name or Logo may not be used    *
      * in any advertising or publicity pertaining to the use of the  *
      * software without the written permission of SimoTime           *
      * Technologies.                                                 *
      *                                                               *
      * Permission to use, copy and modify this software for any      *
      * non-commercial purpose and without fee is hereby granted,     *
      * provided the SimoTime copyright notice appear on all copies   *
      * of the software. The SimoTime name or Logo may not be used in *
      * any advertising or publicity pertaining to the use of the     *
      * software without the written permission of SimoTime           *
      * Technologies.                                                 *
      *                                                               *
      * SimoTime Technologies makes no warranty or representations    *
      * about the suitability of the software for any purpose. It is  *
      * provided "AS IS" without any expressed or implied warranty,   *
      * including the implied warranties of merchantability, fitness  *
      * for a particular purpose and non-infringement. SimoTime       *
      * Technologies shall not be liable for any direct, indirect,    *
      * special or consequential damages resulting from the loss of   *
      * use, data or projects, whether in an action of contract or    *
      * tort, arising out of or in connection with the use or         *
      * performance of this software                                  *
      *                                                               *
      * SimoTime Technologies                                         *
      * 15 Carnoustie Drive                                           *
      * Novato, CA 94949-5849                                         *
      * 415.883.6565                                                  *
      *                                                               *
      * RESTRICTED RIGHTS LEGEND                                      *
      * Use, duplication, or disclosure by the Government is subject  *
      * to restrictions as set forth in subparagraph (c)(1)(ii) of    *
      * the Rights in Technical Data and Computer Software clause at  *
      * DFARS 52.227-7013 or subparagraphs (c)(1) and (2) of          *
      * Commercial  Computer Software - Restricted Rights  at 48      *
      * CFR 52.227-19, as applicable.  Contact SimoTime Technologies, *
      * 15 Carnoustie Drive, Novato, CA 94949-5849.                   *
      *                                                               *
      *****************************************************************
      *      This program is provided by SimoTime Technologies        *
      *        Our e-mail address is: helpdesk@simotime.com           *
      *     Also, visit our Web Site at http://www.simotime.com       *
      *                                                               *
      *****************************************************************
      *
      *****************************************************************
      * Source Member: SIMORA12.CBL
      * Copy Files:    PASSRA12.CPY
      *****************************************************************
      *
      * SIMORA12 - Erase to End=Of-Field (EOF) after first space and
      * then do a Right-Adjust, Zero-Fill for a 12 byte field.
      *
      * EXECUTION or CALLING PROTOCOL
      * -----------------------------
      * CALL 'SIMORA12' USING RA12-PASS-AREA.
      *
      *****************************************************************
      *
      * MAINTENANCE
      * -----------
      * 1997/02/27 Simmons, Created program.
      * 1997/02/27 Simmons, No changes to date.
      *
      *****************************************************************
      *
       DATA DIVISION.
       WORKING-STORAGE SECTION.
       01  Z-X12                   pic 9(3)    value 0.

      *****************************************************************
       LINKAGE SECTION.
       COPY PASSRA12.

      *****************************************************************
       PROCEDURE DIVISION using RA12-PASS-AREA.
           add 16 to ZERO giving RA12-RESPOND
      *    The following INSPECT statement will erase to end-of-field
      *    any characters after the first space character.
           inspect RA12-BUFFER
                   replacing CHARACTERS by ' ' after initial ' '

      *    The following IF logic is for performance. It quickly
      *    reduces the number of loops for the PERFORM logic.
           if  RA12-BUFFER(7:6) = SPACES
               if  RA12-BUFFER(4:3) = SPACES
                   move RA12-BUFFER(1:3) to RA12-BUFFER(10:3)
                   move all ZEROES     to RA12-BUFFER(1:9)
               else
                   move RA12-BUFFER(1:6) to RA12-BUFFER(7:6)
                   move all ZEROES     to RA12-BUFFER(1:6)
               end-if
           else
               if  RA12-BUFFER(10:3) = SPACES
      *            The following three MOVE statements are used to
      *            avoid a potential problem with an overlapping MOVE.
                   move RA12-BUFFER(7:3) to RA12-BUFFER(10:3)
                   move RA12-BUFFER(4:3) to RA12-BUFFER(7:3)
                   move RA12-BUFFER(1:3) to RA12-BUFFER(4:3)
                   move all ZEROES     to RA12-BUFFER(1:3)
               end-if
           end-if

           perform until RA12-BUFFER(12:1) not = SPACE
               if  RA12-BUFFER(12:1) = SPACE
                   add 11 to ZERO giving Z-X12
                   perform 11 times
                     move RA12-BUFFER(Z-X12:1) to RA12-BUFFER
                     (Z-X12 + 1:1)
                     subtract 1 from Z-X12
                   end-perform
                   move ZERO to RA12-BUFFER(1:1)
               end-if
           end-perform

           if  RA12-BUFFER NUMERIC
               move ZERO to RA12-RESPOND
           else
               add 8 to ZERO giving RA12-RESPOND
           end-if

           GOBACK.
      *****************************************************************
      *      This example is provided by SimoTime Technologies        *
      *        Our e-mail address is: helpdesk@simotime.com           *
      *     Also, visit our Web Site at http://www.simotime.com       *
      *****************************************************************
